@@ -1,59 +1,61 @@
-#' Collapse a "tidy" data frame to matrices in a data frame (\code{matsindf})
+#' Collapse a "tidy" data frame to matrices in a data frame `matsindf`)
 #'
 #' A "tidy" data frame contains information that can be collapsed into matrices,
 #' including columns for
 #' matrix names, row names, column names, row types, column types, and values (entries in matrices).
-#' These column names are specified as strings by the \code{matnames}, \code{rownames}, \code{colnames},
-#' \code{rowtypes}, \code{coltypes}, and \code{values} arguments to \link{collapse_to_matrices}, respectively.
-#' A \pkg{matsindf}-style matrix has named rows and columns.
-#' In addition, \pkg{matsindf}-style matrices have "types" for row and column information,
+#' These column names are specified as strings by the `matnames`, `rownames`, `colnames`,
+#' `rowtypes`, `coltypes`, and `values` arguments to `collapse_to_matrices()`, respectively.
+#' A `matsindf`-style matrix has named rows and columns.
+#' In addition, `matsindf`-style matrices have "types" for row and column information,
 #' such as "Commodities", "Industries", "Products", or "Machines".
-#' The row and column types for the \pkg{matsindf}-style matrices are stored as attributes on the matrix
-#' (\code{rowtype} and \code{coltype}),
-#' which can be accessed with the \code{\link[matsbyname]{rowtype}} and \code{\link[matsbyname]{coltype}} functions
-#' of the \pkg{matsbyname} package.
-#' Row and column types are both respected and propagated by the various \code{_byname} functions
-#' of the \pkg{matsbyname} package.
-#' Use the \code{*_byname} functions when you do operations on the \pkg{matsindf}-style matrices.
-#' The \pkg{matsindf}-style matrices will be stored
-#' in a column with same name as the incoming \code{values} column.
+#' The row and column types for the `matsindf`-style matrices are stored as attributes on the matrix
+#' (`rowtype` and `coltype`),
+#' which can be accessed with the functions `matsbyname::rowtype()` and `matsbyname::coltype()`.=
+#' Row and column types are both respected and propagated by the various `*_byname` functions
+#' of the `matsbyname` package.
+#' Use the `*_byname` functions when you do operations on the `matsindf`-style matrices.
+#' The `matsindf`-style matrices will be stored
+#' in a column with same name as the incoming `values` column.
 
-#' This function is similar to \code{\link[tidyr]{nest}}, which stores data frames into a cell of a data frame.
-#' With \code{collapse_to_matrices}, matrices are created.
-#' This function is similar to \code{\link{summarise}} in that groups are respected.
+#' This function is similar to `tidyr::nest()`, which stores data frames into a cell of a data frame.
+#' With `collapse_to_matrices`, matrices are created.
+#' This function respects groups, like `dplyr::summarise()`.
 #' (In fact, calls to this function may not work properly unless grouping is provided.
 #' Errors of the form "Error: Duplicate identifiers for rows ..." are usually fixed by
-#' grouping \code{.DF} prior to calling this function.)
-#' The usual approach is to \code{\link{group_by}} the \code{matnames} column
+#' grouping `.DF` prior to calling this function.)
+#' The usual approach is to `dplyr::group_by()` the `matnames` column
 #' and any other columns to be preserved in the output.
 #' Note that execution is halted if any of
-#' \code{rownames}, \code{rowtypes}, \code{colnames}, \code{coltypes}, or \code{values} is a grouping variable.
-#' \code{rowtypes} and \code{coltypes} should be the same for all rows of the same matrix;
+#' `rownames`, `colnames`, `rowtypes`, `coltypes`, or `values` is a grouping variable in `.DF`.
+#' `rowtypes` and `coltypes` should be the same for all rows of the same matrix in `.DF`;
 #' execution is halted if that is not the case.
-#' \code{\link{spread}}ing the output by \code{matnames} may be necessary before calculations are done on the matrices.
+#' `tidyr::pivot_wider()`ing the output by `matnames` may be necessary before
+#' calculations are done on the collapsed matrices.
 #' See the example.
 #'
 #' Groups are not preserved on output.
 #'
 #' @param .DF the "tidy" data frame
-#' @param matnames a string identifying the column in \code{.DF} containing matrix names for matrices to be created.
-#'                 Default is "\code{matnames}".
-#' @param matvals  a string identifying the column in \code{.DF} containing values to be inserted into the matrices to be created.
+#' @param matnames A string identifying the column in `.DF` containing matrix names for matrices to be created.
+#'                 Default is "matnames".
+#' @param matvals  A string identifying the column in `.DF` containing values to be inserted into the matrices to be created.
 #'                 This will also be the name of the column in the output containing matrices formed from the
-#'                 data in the \code{matvals} column.
-#'                 Default is "\code{matvals}".
-#' @param rownames a string identifying the column in \code{.DF} containing row names for matrices to be created.
-#'                 Default is "\code{rownames}".
-#' @param colnames a string identifying the column in \code{.DF} containing column names for matrices to be created.
-#'                 Default is "\code{colnames}".
-#' @param rowtypes optional string identifying the column in \code{.DF} containing the type of values in rows of the matrices to be created.
-#'                 Default is "\code{rowtypes}".
-#' @param coltypes optional string identifying the column in \code{.DF} containing the type of values in columns of the matrices to be created
-#'                 Default is "\code{coltypes}".
+#'                 data in the `matvals` column.
+#'                 Default is "matvals".
+#' @param rownames A string identifying the column in `.DF` containing row names for matrices to be created.
+#'                 Default is "rownames".
+#' @param colnames A string identifying the column in `.DF` containing column names for matrices to be created.
+#'                 Default is "colnames".
+#' @param rowtypes An optional string identifying the column in `.DF` containing the type of values in rows of the matrices to be created.
+#'                 Default is `if ("rowtypes" %in% names(.DF)) "rowtypes" else NULL`,
+#'                 so that failure to set the rowtypes argument will give `NULL`, as appropriate.
+#' @param coltypes An optional string identifying the column in `.DF` containing the type of values in columns of the matrices to be created
+#'                 Default is `if ("coltypes" %in% names(.DF)) "rowtypes" else NULL`,
+#'                 so that failure to set the coltypes argument will give `NULL`, as appropriate.
 #'
-#' @return a data frame with matrices in columns
+#' @return A data frame with matrices in the `matvals` column.
 #'
-#' @seealso \code{\link[tidyr]{nest}} and \code{\link[dplyr]{summarise}}.
+#' @seealso `tidyr::nest()` and `dplyr::summarise()`.
 #'
 #' @export
 #'
@@ -83,9 +85,10 @@
 #' mats <- collapse_to_matrices(tidy, matnames = "matrix", matvals = "vals",
 #'                              rownames = "row", colnames = "col",
 #'                              rowtypes = "rowtypes", coltypes = "coltypes")
-#' mats %>% spread(key = matrix, value = vals)
+#' mats %>% pivot_wider(names_from = matrix, values_from = vals)
 collapse_to_matrices <- function(.DF, matnames = "matnames", matvals = "matvals", rownames = "rownames", colnames = "colnames",
-                                 rowtypes = "rowtypes", coltypes = "coltypes"){
+                                 rowtypes = if ("rowtypes" %in% names(.DF)) "rowtypes" else NULL,
+                                 coltypes = if ("coltypes" %in% names(.DF)) "coltypes" else NULL) {
   # Ensure that none of rownames, colnames, or values is a group variable.
   # These can't be in the group variables.
   # If they were, we wouldn't be able to summarise them into the matrices.
@@ -106,8 +109,8 @@ collapse_to_matrices <- function(.DF, matnames = "matnames", matvals = "matvals"
     stop(paste("One of rowtypes or coltypes was non-NULL while the other was NULL.",
                "Both need to be NULL or both need to be non-NULL in collapse_to_matrices."))
   }
-  # If we get here, both rowtypes and coltypes are not (NULL).
-  # Thus, we need to test only for the one of them being non-NULL.
+  # If we get here, both rowtypes and coltypes are not NULL.
+  # Thus, we need to test only for the one of them being non-NULL
   .DF %>%
     {if (!is.null(rowtypes)) {
       dplyr::group_by(.DF, !!as.name(rowtypes), !!as.name(coltypes), .add = TRUE)
@@ -120,7 +123,6 @@ collapse_to_matrices <- function(.DF, matnames = "matnames", matvals = "matvals"
                                     rowtypes = rowtypes, coltypes = coltypes)
     ) %>%
     dplyr::select(!!!dplyr::group_vars(.DF), !!matvals) %>%
-    # data.frame(check.names = FALSE)
-    # As of R 4.0.0, stringsAsFactors = FALSE will be the default.
-    data.frame(check.names = FALSE, stringsAsFactors = FALSE)
+    data.frame(check.names = FALSE)
 }
+
